@@ -52,6 +52,8 @@ DEFAULT_PORTS = {
 # an explicit list. There are many such schemes in various URIs.
 COLON_SEPARATED_SCHEMES = [
     'mailto',
+    'tel',
+    'sms'
     ]
 
 
